@@ -22,7 +22,7 @@ class UUIDType(ScalarCoercible, types.TypeDecorator):
             __tablename__ = 'user'
 
             # Pass `binary=False` to fallback to CHAR instead of BINARY
-            id = sa.Column(UUIDType(binary=False), primary_key=True)
+            id = sa.Column(UUIDType(binary=False), primary_key=True, default=uuid.uuid4)
     """
     impl = types.BINARY(16)
 
@@ -63,6 +63,9 @@ class UUIDType(ScalarCoercible, types.TypeDecorator):
 
         return value
 
+    def process_literal_param(self, value, dialect):
+        return "'{}'".format(value) if value else value
+
     def process_bind_param(self, value, dialect):
         if value is None:
             return value
@@ -70,7 +73,11 @@ class UUIDType(ScalarCoercible, types.TypeDecorator):
         if not isinstance(value, uuid.UUID):
             value = self._coerce(value)
 
-        if self.native and dialect.name in ('postgresql', 'mssql', 'cockroachdb'):
+        if self.native and dialect.name in (
+            'postgresql',
+            'mssql',
+            'cockroachdb'
+        ):
             return str(value)
 
         return value.bytes if self.binary else value.hex
@@ -79,7 +86,11 @@ class UUIDType(ScalarCoercible, types.TypeDecorator):
         if value is None:
             return value
 
-        if self.native and dialect.name in ('postgresql', 'mssql', 'cockroachdb'):
+        if self.native and dialect.name in (
+            'postgresql',
+            'mssql',
+            'cockroachdb'
+        ):
             if isinstance(value, uuid.UUID):
                 # Some drivers convert PostgreSQL's uuid values to
                 # Python's uuid.UUID objects by themselves
